@@ -1,4 +1,8 @@
 from .base import Cache, CacheBackendProtocol
 from .simple_cache_backend import SimpleCacheBackend
 
-__all__ = ("CacheBackendProtocol", "SimpleCacheBackend", "Cache")
+__all__ = (
+    "CacheBackendProtocol",
+    "SimpleCacheBackend",
+    "Cache",
+)
